Implements the XH component using a delay Susceptible-Infectious-Prophylaxis (SIPd) model of malaria infection dynamics. This is the delay differential equation version of the SIP model, in which the duration of prophylaxis \(\eta\) is modelled as a fixed delay.

State Variables

H

total human (or host) population density

I

density of infectious humans

P

density of humans under chemoprophylaxis

Note: susceptible density \(S = H - I - P\).

Parameters

b

transmission probability from mosquito to human

c

transmission probability from human to mosquito

r

clearance rate for infections

rho

fraction of new infections immediately treated / entering \(P\)

xi

rate of mass drug administration (\(\xi\))

eta

prophylaxis duration (fixed delay, in days)

B

time-dependent birth rate function \(B(t, H)\)

D

linear operator (matrix) for mortality, migration, aging, and transfers

Dynamics

$$ \begin{array}{rl} dH/dt &= B(t,H) + D \cdot H \\ dI/dt &= (1-\rho)hS - (r + \xi)I + D \cdot I \\ dP/dt &= (\rho h + \xi)S + \xi I - \dot{\mathcal{H}}(P) + D \cdot P \\ \end{array}$$ where \(\dot{\mathcal{H}}(P)\) is the delayed outflow from \(P\), computed via deSolve::lagderiv.