A staged aquatic mosquito development model with four larval instars. Population density is structured into eggs (\(E\)), four larval instars (\(L_1\)–\(L_4\)), and pupae (\(P\)). Density-dependent regulation operates through a weighted mean crowding index $$L = w_1 L_1 + w_2 L_2 + w_3 L_3 + L_4,$$ allowing each instar to contribute differently to crowding. Each larval instar has its own maturation rate, density-dependent maturation delay, density-independent mortality, and density-dependent mortality.

State Variables

E

egg density per habitat

L1

first instar larval density per habitat

L2

second instar larval density per habitat

L3

third instar larval density per habitat

L4

fourth instar larval density per habitat

P

pupal density per habitat

Parameters

psi_E

egg maturation (hatching) rate (\(\psi_E\))

phi_E

egg mortality rate (\(\phi_E\))

psi1, psi2, psi3, psi4

larval instar maturation rates (\(\psi_i\))

xi1, xi2, xi3, xi4

delayed maturation responses to mean crowding (\(\xi_i\))

phi1, phi2, phi3, phi4

density-independent larval mortality rates (\(\phi_i\))

theta1, theta2, theta3, theta4

density-dependent larval mortality slopes (\(\theta_i\))

phi_P

pupal mortality rate (\(\phi_P\))

psi_P

pupal maturation (emergence) rate (\(\psi_P\))

w1, w2, w3

contributions of \(L_1\), \(L_2\), and \(L_3\) to mean crowding (\(w_i\))

Egg Laying

eta

the egg laying rate (\(\eta\))

Mean Crowding

$$L = w_1 L_1 + w_2 L_2 + w_3 L_3 + L_4$$

The fourth instar \(L_4\) acts as the reference stage (\(w_4 = 1\)). Setting all \(w_i = 1\) recovers unweighted total larval density.

Dynamics

$$dE/dt = \eta - (\psi_E + \phi_E) E$$ $$dL_1/dt = \psi_E E - \psi_1 L_1 e^{-\xi_1 L} - (\phi_1 + \theta_1 L) L_1$$ $$dL_2/dt = \psi_1 L_1 e^{-\xi_1 L} - \psi_2 L_2 e^{-\xi_2 L} - (\phi_2 + \theta_2 L) L_2$$ $$dL_3/dt = \psi_2 L_2 e^{-\xi_2 L} - \psi_3 L_3 e^{-\xi_3 L} - (\phi_3 + \theta_3 L) L_3$$ $$dL_4/dt = \psi_3 L_3 e^{-\xi_3 L} - \psi_4 L_4 e^{-\xi_4 L} - (\phi_4 + \theta_4 L) L_4$$ $$dP/dt = \psi_4 L_4 e^{-\xi_4 L} - (\phi_P + \psi_P) P$$

Emergence

The emergence rate of adult, female mosquitoes from each habitat is: $$\alpha = \psi_P P$$